@@ -1,14 +1,15 @@
 package Defaults::Modern;
-$Defaults::Modern::VERSION = '0.008001';
+$Defaults::Modern::VERSION = '0.009001';
 use v5.14;
 
-use strict; use warnings FATAL => 'all';
-
-no bareword::filehandles;
+use strictures 2;
 no indirect ':fatal';
+no bareword::filehandles;
 
 use Module::Runtime 'use_package_optimistically';
 use Try::Tiny;
+use Import::Into;
+
 
 use Carp    ();
 use feature ();
@@ -31,8 +32,6 @@ use Type::Utils               ();
 use List::Objects::Types      ();
 
 
-use Import::Into;
-
 sub import {
   my $class = shift;
   my $pkg = caller;
@@ -86,16 +85,14 @@ sub import {
   );
   
   # Pragmas
-  strict->import;
-  warnings->import(FATAL => 'all');
+  strictures->import::into($pkg, version => 2);
+  bareword::filehandles->unimport;
+  indirect->unimport(':fatal');
   warnings->unimport('once');
   if ($] >= 5.018) {
     warnings->unimport('experimental');
   }
 
-  bareword::filehandles->unimport;
-  indirect->unimport(':fatal');
-
   feature->import(':5.14');
   feature->unimport('switch');
 
@@ -132,7 +129,9 @@ sub import {
   );
 
   Path::Tiny->import::into($pkg, 'path');
+
   PerlX::Maybe->import::into($pkg, qw/maybe provided/);
+
   Try::Tiny->import::into($pkg);
   Switch::Plain->import;
 
@@ -149,12 +148,13 @@ sub import {
 
   for my $typelib (@$mytypelibs, @$typelibs) {
     use_package_optimistically($typelib)->import::into($pkg, -all);
-    try {
-      Type::Registry->for_class($pkg)->add_types($typelib);
-    } catch {
+# Irrelevant with Type::Tiny-1.x ->
+#    try {
+#      Type::Registry->for_class($pkg)->add_types($typelib);
+#    } catch {
       # Usually conflicts; whine but prefer user's previous imports:
-      Carp::carp($_)
-    };
+#      Carp::carp($_)
+#    };
   }
 
   if (defined $params{moo}) {
@@ -234,8 +234,9 @@ When you C<use Defaults::Modern>, you get:
 
 =item *
 
-L<strict> and fatal L<warnings> except for C<once>; additionally disallow
-L<bareword::filehandles> and L<indirect> method calls
+L<strictures> (version 2), which enables L<strict> and makes most warnings
+fatal; additionally L<bareword::filehandles> and L<indirect> method calls are
+disallowed explicitly (not just in development environments)
 
 =item *
 
@@ -305,6 +306,10 @@ L<Type::Library>), they can be specified at import time:
     -all,
     -with_types => [ 'Types::Mine' ],
 
+This feature is unnecessary with L<Type::Tiny> version 1.x and higher, which
+will automatically register L<Type::Library>-based types in the caller's
+L<Type::Registry>.
+
 If you import the tag C<autobox_lists>, ARRAY and HASH type references are autoboxed
 via L<List::Objects::WithUtils>:
 
@@ -314,9 +319,8 @@ via L<List::Objects::WithUtils>:
 L<Moo> and L<MooX::late> are depended upon in order to guarantee their
 availability, but not automatically imported:
 
-  use Moo;
-  use MooX::late;
   use Defaults::Modern;
+  use Moo;  use MooX::late;
 
   has foo => (
     is  => 'ro',
