@@ -1,6 +1,6 @@
 package Defaults::Modern::Define;
-$Defaults::Modern::Define::VERSION = '0.008001';
-use strict; use warnings FATAL => 'all';
+$Defaults::Modern::Define::VERSION = '0.009001';
+use strictures 2;
 
 # Forked from TOBYINK's PerlX::Define, copyright Toby Inkster
 #  (... to avoid the Moops dep)
